# Django CKeditor Skins

Providing skins to use with [django-ckeditor](https://github.com/django-ckeditor/django-ckeditor)

### Install

```shell
pip install django-ckeditor-skins
```

- Add `ckeditor_skins` to your `INSTALLED_APPS`
- Run static collection
